@@ -14,13 +14,14 @@ export default function PropertyEnum(_ref) {
       onUpdate = _ref.onUpdate,
       configs = _ref.configs,
       sourceElement = _ref.sourceElement,
-      internalState = _ref.internalState;
+      internalState = _ref.internalState,
+      state = _ref.state;
 
 
   var update = function update(val) {
 
     if (configs.hook) {
-      return configs.hook(val).then(function (_val) {
+      return configs.hook(val, sourceElement, internalState, state).then(function (_val) {
         return onUpdate(_val);
       });
     }
@@ -77,5 +78,6 @@ PropertyEnum.propTypes = {
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
   sourceElement: PropTypes.object,
-  internalState: PropTypes.object
+  internalState: PropTypes.object,
+  state: PropTypes.object.isRequired
 };
\ No newline at end of file
