@@ -8,7 +8,7 @@ export default {
   "Cancel": "Cancel",
   "Save": "Save",
   "Layer config": "Layer config",
-  "name": "name",
+  "Name": "Name",
   "opacity": "opacity",
   "altitude": "altitude",
   "order": "order",
@@ -34,9 +34,13 @@ export default {
   "Catalog" : "Catalog",
   "Rotation" : "Rotation",
   "Altitude": "Altitude",
-  "Name" : "Name",
   "Would you want to start a new Project?": "Would you want to start a new Project?",
   "Copy":"Copy",
   "Paste":"Paste",
-  "Search Element":"Search Element"
+  "Search Element":"Search Element",
+  "Last Selected":"Last Selected",
+  "Length":"Length",
+  "Lines":"Lines",
+  "Holes":"Holes",
+  "Items":"Items"
 }
